/******************************************************************************
  This source file is part of the Avogadro project.
  This source code is released under the 3-Clause BSD License, (see "LICENSE").
******************************************************************************/

#include "version.h"

namespace Avogadro {

const char* version()
{
  return AvogadroLibs_VERSION;
}

} // namespace Avogadro
